import {
  UserLayout,
  BasicLayout,
  BlankLayout,
  BigScreen,
  PageView
} from '@/layouts'

export default {
        path: '/allocationManagement',
        redirect: '/allocationManagement/transferOut',
        component: PageView,
        meta: {
          title: '调拨管理',
          icon: 'cluster',
          permission: 'M_allocationManagement'
        },
        children: [
          {
            path: '/allocationManagement/transferOut',
            redirect: '/allocationManagement/transferOut/list',
            name: 'transferOut',
            component: BlankLayout,
            meta: {
              title: '调拨列表',
              icon: 'pull-request',
              permission: 'M_transferOutList'
            },
            hideChildrenInMenu: true,
            children: [
              {
                path: 'list',
                name: 'transferOutList',
                component: () => import(/* webpackChunkName: "allocationManagement" */ '@/views/allocationManagement/transferOut/list.vue'),
                meta: {
                  title: '调拨列表',
                  icon: 'pull-request',
                  hidden: true,
                  permission: 'M_transferOutList'
                }
              },
              {
                path: 'add/:sn/:dealerLevel',
                name: 'transferOutAdd',
                component: () => import(/* webpackChunkName: "allocationManagement" */ '@/views/allocationManagement/transferOut/edit.vue'),
                meta: {
                  title: '新增调拨单',
                  icon: 'pull-request',
                  hidden: true,
                  permission: 'M_transferOut_edit'
                }
              },
              {
                path: 'edit/:sn/:dealerLevel',
                name: 'transferOutEdit',
                component: () => import(/* webpackChunkName: "allocationManagement" */ '@/views/allocationManagement/transferOut/edit.vue'),
                meta: {
                  title: '编辑调拨单',
                  icon: 'pull-request',
                  hidden: true,
                  permission: 'M_transferOut_edit'
                }
              },
              {
                path: 'detail/:sn',
                name: 'transferOutDetail',
                component: () => import(/* webpackChunkName: "allocationManagement" */ '@/views/allocationManagement/transferOut/detail.vue'),
                meta: {
                  title: '调拨单详情',
                  icon: 'pull-request',
                  hidden: true,
                  replaceTab: true,
                  permission: 'M_transferOut_detail'
                }
              }
            ]
          },
          {
            path: '/allocationManagement/transfersPrint',
            redirect: '/allocationManagement/transfersPrint/list',
            name: 'transfersPrint',
            component: BlankLayout,
            meta: {
              title: '调拨打印',
              icon: 'pull-request',
              permission: 'M_transfersPrintList'
            },
            hideChildrenInMenu: true,
            children: [
              {
                path: 'list',
                name: 'transfersPrintList',
                component: () => import(/* webpackChunkName: "allocationManagement" */ '@/views/allocationManagement/transfersPrint/list.vue'),
                meta: {
                  title: '调拨打印',
                  icon: 'pull-request',
                  hidden: true,
                  permission: 'M_transfersPrintList'
                }
              }
            ]
          },
          {
            path: '/allocationManagement/matchSendOutOrder',
            redirect: '/allocationManagement/matchSendOutOrder/list',
            name: 'matchSendOutOrderAllocation',
            component: BlankLayout,
            meta: {
              title: '调拨发货对单',
              icon: 'vertical-align-bottom',
              permission: 'M_matchSendOutOrderAllocationList'
            },
            hideChildrenInMenu: true,
            children: [
              {
                path: 'list',
                name: 'matchSendOutOrderAllocationList',
                component: () => import(/* webpackChunkName: "allocationManagement" */ '@/views/allocationManagement/matchSendOutOrder/list.vue'),
                meta: {
                  title: '调拨发货对单',
                  icon: 'vertical-align-bottom',
                  hidden: true,
                  permission: 'M_matchSendOutOrderAllocationList'
                }
              }
            ]
          },
          {
            path: '/allocationManagement/transferReturn',
            redirect: '/allocationManagement/transferReturn/list',
            name: 'transferReturn',
            component: BlankLayout,
            meta: {
              title: '调拨退货列表',
              icon: 'pull-request',
              permission: 'M_transferReturnList'
            },
            hideChildrenInMenu: true,
            children: [
              {
                path: 'list',
                name: 'transferReturnList',
                component: () => import(/* webpackChunkName: "allocationManagement" */ '@/views/allocationManagement/transferReturn/list.vue'),
                meta: {
                  title: '调拨退货列表',
                  icon: 'pull-request',
                  hidden: true,
                  permission: 'M_transferReturnList'
                }
              },
              {
                path: 'editGrap/:sn/:targetType',
                name: 'transferReturnGrpEdit',
                component: () => import(/* webpackChunkName: "allocationManagement" */ '@/views/allocationManagement/transferReturn/editGrp.vue'),
                meta: {
                  title: '编辑调拨退货单(抓单)',
                  icon: 'pull-request',
                  hidden: true,
                  permission: 'B_transferReturnEdit'
                }
              },
              {
                path: 'edit/:sn/:targetType/:dealerLevel',
                name: 'transferReturnEdit',
                component: () => import(/* webpackChunkName: "allocationManagement" */ '@/views/allocationManagement/transferReturn/edit.vue'),
                meta: {
                  title: '编辑调拨退货单(不抓单)',
                  icon: 'pull-request',
                  hidden: true,
                  permission: 'B_transferReturnEdit'
                }
              },
              {
                path: 'detail/:sn',
                name: 'transferReturnDetail',
                component: () => import(/* webpackChunkName: "allocationManagement" */ '@/views/allocationManagement/transferReturn/detail.vue'),
                meta: {
                  title: '调拨退货单详情',
                  icon: 'pull-request',
                  replaceTab: true,
                  hidden: true,
                  permission: 'M_transferReturnDetail'
                }
              },
              {
                path: 'check/:sn/:grabFlag',
                name: 'transferReturnCheck',
                component: () => import(/* webpackChunkName: "allocationManagement" */ '@/views/allocationManagement/transferReturn/check.vue'),
                meta: {
                  title: '调拨退货品检',
                  icon: 'fund',
                  replaceTab: true,
                  hidden: true,
                  permission: 'M_transferReturnCheck'
                }
              }
            ]
          },
          {
            path: '/allocationManagement/allocateReturnConfirmation',
            redirect: '/allocationManagement/allocateReturnConfirmation/list',
            name: 'allocateReturnConfirmation',
            component: BlankLayout,
            meta: {
              title: '调拨退货确认',
              icon: 'vertical-align-top',
              permission: 'M_allocateReturnConfirmationList'
            },
            hideChildrenInMenu: true,
            children: [
              {
                path: 'list',
                name: 'allocateReturnConfirmationList',
                component: () => import(/* webpackChunkName: "allocationManagement" */ '@/views/allocationManagement/allocateReturnConfirmation/list.vue'),
                meta: {
                  title: '调拨退货确认列表',
                  icon: 'vertical-align-top',
                  hidden: true,
                  permission: 'M_allocateReturnConfirmationList'
                }
              }
            ]
          },
          {
            path: '/allocationManagement/allocationList',
            redirect: '/allocationManagement/allocationList/list',
            name: 'allocationList',
            component: BlankLayout,
            meta: {
              title: '调拨一览表',
              icon: 'vertical-align-top',
              permission: 'M_allocationList'
            },
            hideChildrenInMenu: true,
            children: [
              {
                path: 'list',
                name: 'allocationMainList',
                component: () => import(/* webpackChunkName: "allocationManagement" */ '@/views/allocationManagement/allocationList/list.vue'),
                meta: {
                  title: '调拨一览表',
                  icon: 'vertical-align-top',
                  hidden: true,
                  permission: 'M_allocationList'
                }
              }
            ]
          }
        ]
      }