import {
  UserLayout,
  BasicLayout,
  BlankLayout,
  BigScreen,
  PageView
} from '@/layouts'

export default {
        path: '/inventoryManagement',
        redirect: '/inventoryManagement/inventoryQuery',
        component: PageView,
        meta: {
          title: '库存管理',
          icon: 'shop',
          permission: 'M_inventoryManagement'
        },
        children: [
          {
            path: '/inventoryManagement/inventoryQuery',
            redirect: '/inventoryManagement/inventoryQuery/list',
            name: 'inventoryQuery',
            component: BlankLayout,
            meta: {
              title: '库存查询',
              icon: 'monitor',
              permission: 'M_inventoryQueryList'
            },
            hideChildrenInMenu: true,
            children: [
              {
                path: 'list',
                name: 'inventoryQueryList',
                component: () => import(/* webpackChunkName: "inventoryManagement" */ '@/views/inventoryManagement/inventoryQuery/list.vue'),
                meta: {
                  title: '库存列表',
                  icon: 'monitor',
                  hidden: true,
                  permission: 'M_inventoryQueryList'
                }
              },
              {
                path: 'warehouseDetail/:sn/:warehouseSn',
                name: 'inventoryQueryWarehouseDetail',
                component: () => import(/* webpackChunkName: "inventoryManagement" */ '@/views/inventoryManagement/inventoryQuery/warehouseDetail.vue'),
                meta: {
                  title: '出入库明细',
                  icon: 'monitor',
                  replaceTab: true,
                  hidden: true,
                  permission: 'B_inventoryQuery_rkDetail'
                }
              }
            ]
          },
          {
            path: '/inventoryManagement/inventoryCheck',
            redirect: '/inventoryManagement/inventoryCheck/list/0',
            name: 'inventoryCheck',
            component: BlankLayout,
            meta: {
              title: '库存盘点',
              icon: 'monitor',
              permission: 'M_inventoryCheckList'
            },
            hideChildrenInMenu: true,
            children: [
              {
                path: 'list/:type',
                name: 'inventoryCheckList',
                component: () => import(/* webpackChunkName: "inventoryManagement" */ '@/views/inventoryManagement/inventoryCheck/list.vue'),
                meta: {
                  title: '库存盘点列表',
                  icon: 'monitor',
                  hidden: true,
                  permission: 'M_inventoryCheckList'
                }
              },
              {
                path: 'detail/:sn',
                name: 'inventoryCheckDetail',
                component: () => import(/* webpackChunkName: "inventoryManagement" */ '@/views/inventoryManagement/inventoryCheck/detail.vue'),
                meta: {
                  title: '库存盘点详情',
                  icon: 'monitor',
                  hidden: true,
                  replaceTab: true,
                  permission: 'B_inventoryCheckDetail'
                }
              }
            ]
          },
          {
            path: '/inventoryManagement/makeInventory',
            redirect: '/inventoryManagement/makeInventory/list',
            name: 'makeInventory',
            component: BlankLayout,
            meta: {
              title: '盘点人盘点',
              icon: 'monitor',
              permission: 'M_inventoryMakeInventoryList'
            },
            hideChildrenInMenu: true,
            children: [
              {
                path: 'list',
                name: 'makeInventoryList',
                component: () => import(/* webpackChunkName: "inventoryManagement" */ '@/views/inventoryManagement/makeInventory/list.vue'),
                meta: {
                  title: '盘点人盘点列表',
                  icon: 'monitor',
                  hidden: true,
                  permission: 'M_inventoryMakeInventoryList'
                }
              },
              {
                path: 'check/:sn',
                name: 'makeInventoryCheck',
                component: () => import(/* webpackChunkName: "inventoryManagement" */ '@/views/inventoryManagement/makeInventory/check.vue'),
                meta: {
                  title: '盘点人盘点',
                  icon: 'monitor',
                  hidden: true,
                  replaceTab: true,
                  permission: 'B_inventoryMakeInventoryCheck'
                }
              }
            ]
          },
          {
            path: '/inventoryManagement/supervisionDisk',
            redirect: '/inventoryManagement/supervisionDisk/list',
            name: 'supervisionDisk',
            component: BlankLayout,
            meta: {
              title: '监盘人盘点',
              icon: 'monitor',
              permission: 'M_supervisionDiskList'
            },
            hideChildrenInMenu: true,
            children: [
              {
                path: 'list',
                name: 'supervisionDiskList',
                component: () => import(/* webpackChunkName: "inventoryManagement" */ '@/views/inventoryManagement/supervisionDisk/list.vue'),
                meta: {
                  title: '监盘人盘点列表',
                  icon: 'monitor',
                  hidden: true,
                  permission: 'M_supervisionDiskList'
                }
              },
              {
                path: 'check/:sn',
                name: 'supervisionDiskCheck',
                component: () => import(/* webpackChunkName: "inventoryManagement" */ '@/views/inventoryManagement/supervisionDisk/check.vue'),
                meta: {
                  title: '监盘人监盘',
                  icon: 'monitor',
                  replaceTab: true,
                  hidden: true,
                  permission: 'B_supervisionDiskCheck'
                }
              }
            ]
          },
          {
            path: '/inventoryManagement/inventoryConfirmation',
            redirect: '/inventoryManagement/inventoryConfirmation/list',
            name: 'inventoryConfirmation',
            component: BlankLayout,
            meta: {
              title: '盘点确认',
              icon: 'monitor',
              permission: 'M_inventoryConfirmationList'
            },
            hideChildrenInMenu: true,
            children: [
              {
                path: 'list',
                name: 'inventoryConfirmationList',
                component: () => import(/* webpackChunkName: "inventoryManagement" */ '@/views/inventoryManagement/inventoryConfirmation/list.vue'),
                meta: {
                  title: '盘点确认列表',
                  icon: 'monitor',
                  hidden: true,
                  permission: 'M_inventoryConfirmationList'
                }
              },
              {
                path: 'detail/:sn',
                name: 'inventoryConfirmationDetail',
                component: () => import(/* webpackChunkName: "inventoryManagement" */ '@/views/inventoryManagement/inventoryConfirmation/detail.vue'),
                meta: {
                  title: '盘点确认详情',
                  icon: 'monitor',
                  hidden: true,
                  permission: 'B_inventoryConfirmationDetail'
                }
              }
            ]
          },
          {
            path: '/inventoryManagement/inventoryWarning',
            redirect: '/inventoryManagement/inventoryWarning/list',
            name: 'inventoryWarning',
            component: BlankLayout,
            meta: {
              title: '库存预警',
              icon: 'monitor',
              permission: 'M_inventoryWarningList'
            },
            hideChildrenInMenu: true,
            children: [
              {
                path: 'list',
                name: 'inventoryWarningList',
                component: () => import(/* webpackChunkName: "inventoryManagement" */ '@/views/inventoryManagement/inventoryWarning/list.vue'),
                meta: {
                  title: '库存预警列表',
                  icon: 'alert',
                  hidden: true,
                  permission: 'M_inventoryWarningList'
                }
              }
            ]
          },
          {
            path: '/inventoryManagement/intelligentReplenishment',
            redirect: '/inventoryManagement/intelligentReplenishment/list',
            name: 'intelligentReplenishment',
            component: BlankLayout,
            meta: {
              title: '智能补货',
              icon: 'monitor',
              permission: 'M_intelligentReplenishmentList'
            },
            hideChildrenInMenu: true,
            children: [
              {
                path: 'list',
                name: 'intelligentReplenishmentList',
                component: () => import(/* webpackChunkName: "inventoryManagement" */ '@/views/inventoryManagement/intelligentReplenishment/list.vue'),
                meta: {
                  title: '智能补货列表',
                  icon: 'monitor',
                  hidden: true,
                  permission: 'M_intelligentReplenishmentList'
                }
              },
              {
                path: 'add/:sn',
                name: 'intelligentReplenishmentAdd',
                component: () => import(/* webpackChunkName: "inventoryManagement" */ '@/views/inventoryManagement/intelligentReplenishment/edit.vue'),
                meta: {
                  title: '新增智能补货',
                  icon: 'monitor',
                  hidden: true,
                  permission: 'B_intelligentReplenishment_edit'
                }
              },
              {
                path: 'edit/:sn',
                name: 'intelligentReplenishmentEdit',
                component: () => import(/* webpackChunkName: "inventoryManagement" */ '@/views/inventoryManagement/intelligentReplenishment/edit.vue'),
                meta: {
                  title: '编辑智能补货',
                  icon: 'monitor',
                  hidden: true,
                  permission: 'B_intelligentReplenishment_edit'
                }
              },
              {
                path: 'set',
                name: 'intelligentReplenishmentSet',
                component: () => import(/* webpackChunkName: "inventoryManagement" */ '@/views/inventoryManagement/intelligentReplenishment/set.vue'),
                meta: {
                  title: '基础信息设置',
                  icon: 'monitor',
                  permission: 'B_intelligentReplenishment_set',
                  replaceTab: true,
                  hidden: true
                }
              },
              {
                path: 'import',
                name: 'intelligentReplenishmentImport',
                component: () => import(/* webpackChunkName: "inventoryManagement" */ '@/views/inventoryManagement/intelligentReplenishment/import.vue'),
                meta: {
                  title: '确认导入',
                  icon: 'monitor',
                  replaceTab: true,
                  hidden: true
                }
              }
            ]
          }
        ]
      }