import {
  UserLayout,
  BasicLayout,
  BlankLayout,
  BigScreen,
  PageView
} from '@/layouts'

export default {
        path: '/productManagement',
        redirect: '/productManagement/productInfo',
        component: PageView,
        meta: {
          title: '产品管理',
          icon: 'shopping',
          permission: 'M_productManagement'
        },
        children: [
          {
            path: '/productManagement/productInfo',
            redirect: '/productManagement/productInfo/list',
            name: 'productInfo',
            component: BlankLayout,
            meta: {
              title: '产品列表',
              icon: 'gold',
              permission: 'M_productInfoList'
            },
            hideChildrenInMenu: true,
            children: [
              {
                path: 'list',
                name: 'productInfoList',
                component: () => import(/* webpackChunkName: "productManagement" */ '@/views/productManagement/productInfo/list.vue'),
                meta: {
                  title: '产品列表',
                  icon: 'gold',
                  hidden: true,
                  permission: 'M_productInfoList'
                }
              },
              {
                path: 'add',
                name: 'productInfoAdd',
                component: () => import(/* webpackChunkName: "productManagement" */ '@/views/productManagement/productInfo/edit.vue'),
                meta: {
                  title: '新增产品',
                  icon: 'gold',
                  hidden: true
                  // permission: 'B_goodsManage_edit'
                }
              },
              {
                path: 'edit/:id/:sn',
                name: 'productInfoEdit',
                component: () => import(/* webpackChunkName: "productManagement" */ '@/views/productManagement/productInfo/edit.vue'),
                meta: {
                  title: '编辑产品',
                  icon: 'gold',
                  hidden: true
                  // permission: 'B_goodsManage_edit'
                }
              }
            ]
          },
          {
            path: '/productManagement/productPricing',
            redirect: '/productManagement/productPricing/list',
            name: 'productPricing',
            component: BlankLayout,
            meta: {
              title: '产品定价',
              icon: 'transaction',
              permission: 'M_productPricingList'
            },
            hideChildrenInMenu: true,
            children: [
              {
                path: 'list',
                name: 'productPricingList',
                component: () => import(/* webpackChunkName: "productManagement" */ '@/views/productManagement/productPricing/list.vue'),
                meta: {
                  title: '产品定价列表',
                  icon: 'transaction',
                  hidden: true,
                  permission: 'M_productPricingList'
                }
              }
            ]
          },
          {
            path: '/productManagement/productLaunchAudit',
            redirect: '/productManagement/productLaunchAudit/list',
            name: 'productLaunchAudit',
            component: BlankLayout,
            meta: {
              title: '产品上线审核',
              icon: 'rise',
              permission: 'M_productLaunchAuditList'
            },
            hideChildrenInMenu: true,
            children: [
              {
                path: 'list',
                name: 'productLaunchAuditList',
                component: () => import(/* webpackChunkName: "productManagement" */ '@/views/productManagement/productLaunchAudit/list.vue'),
                meta: {
                  title: '产品上线审核列表',
                  icon: 'rise',
                  hidden: true,
                  permission: 'M_productLaunchAuditList'
                }
              }
            ]
          },
          {
            path: '/productManagement/newProduct',
            redirect: '/productManagement/newProduct/list/onlineInfo/1',
            name: 'productLaunchInfo',
            component: BlankLayout,
            meta: {
              title: '产品上线信息',
              icon: 'rise',
              permission: 'M_productLaunchInfoList'
            },
            hideChildrenInMenu: true,
            children: [
              {
                path: 'list/:type/:onlineFalg',
                name: 'productLaunchInfoList',
                component: () => import(/* webpackChunkName: "productManagement" */ '@/views/productManagement/newProduct/list.vue'),
                meta: {
                  title: '产品上线信息列表',
                  icon: 'rise',
                  hidden: true,
                  permission: 'M_productLaunchInfoList'
                }
              }
            ]
          },
          {
            path: '/productManagement/productOfflineAudit',
            redirect: '/productManagement/productOfflineAudit/list',
            name: 'productOfflineAudit',
            component: BlankLayout,
            meta: {
              title: '产品下线审核',
              icon: 'fall',
              permission: 'M_productOfflineAuditList'
            },
            hideChildrenInMenu: true,
            children: [
              {
                path: 'list',
                name: 'productOfflineAuditList',
                component: () => import(/* webpackChunkName: "productManagement" */ '@/views/productManagement/productOfflineAudit/list.vue'),
                meta: {
                  title: '产品下线审核列表',
                  icon: 'fall',
                  hidden: true,
                  permission: 'M_productOfflineAuditList'
                }
              }
            ]
          },
          {
            path: '/productManagement/productNotOnline',
            redirect: '/productManagement/productNotOnline/list',
            name: 'productNotOnline',
            component: BlankLayout,
            meta: {
              title: '产品状态信息',
              icon: 'fall',
              permission: 'M_productNotOnlineList'
            },
            hideChildrenInMenu: true,
            children: [
              {
                path: 'list',
                name: 'productNotOnlineList',
                component: () => import(/* webpackChunkName: "productManagement" */ '@/views/productManagement/productNotOnline/list.vue'),
                meta: {
                  title: '产品状态信息列表',
                  icon: 'fall',
                  hidden: true,
                  permission: 'M_productNotOnlineList'
                }
              }
            ]
          },
          {
            path: '/productManagement/priceChangeRecord',
            redirect: '/productManagement/priceChangeRecord/list',
            name: 'priceChangeRecord',
            component: BlankLayout,
            meta: {
              title: '价格变更记录',
              icon: 'profile',
              permission: 'M_priceChangeRecordList'
            },
            hideChildrenInMenu: true,
            children: [
              {
                path: 'list',
                name: 'priceChangeRecordList',
                component: () => import(/* webpackChunkName: "productManagement" */ '@/views/productManagement/priceChangeRecord/list.vue'),
                meta: {
                  title: '价格变更记录列表',
                  icon: 'profile',
                  hidden: true,
                  permission: 'M_priceChangeRecordList'
                }
              }
            ]
          },
          {
            path: '/productManagement/productUniversal',
            redirect: '/productManagement/productUniversal/list',
            name: 'productUniversal',
            component: BlankLayout,
            meta: {
              title: '通用产品管理',
              icon: 'deployment-unit',
              permission: 'M_productUniversalList'
            },
            hideChildrenInMenu: true,
            children: [
              {
                path: 'list',
                name: 'productUniversalList',
                component: () => import(/* webpackChunkName: "productManagement" */ '@/views/productManagement/productUniversal/list.vue'),
                meta: {
                  title: '通用产品列表',
                  icon: 'deployment-unit',
                  hidden: true,
                  permission: 'M_productUniversalList'
                }
              }
            ]
          },
          {
            path: '/productManagement/productLevel',
            redirect: '/productManagement/productLevel/list',
            name: 'productLevel',
            component: BlankLayout,
            meta: {
              title: '产品级别管理',
              icon: 'fund',
              permission: 'M_productLevelList'
            },
            hideChildrenInMenu: true,
            children: [
              {
                path: 'list',
                name: 'productLevelList',
                component: () => import(/* webpackChunkName: "productManagement" */ '@/views/productManagement/productLevel/list.vue'),
                meta: {
                  title: '产品级别列表',
                  icon: 'fund',
                  hidden: true,
                  permission: 'M_productLevelList'
                }
              }
            ]
          },
          {
            path: '/productManagement/productBrand',
            redirect: '/productManagement/productBrand/list',
            name: 'productBrand',
            component: BlankLayout,
            meta: {
              title: '产品品牌管理',
              icon: 'file-ppt',
              permission: 'M_productBrandList'
            },
            hideChildrenInMenu: true,
            children: [
              {
                path: 'list',
                name: 'productBrandList',
                component: () => import(/* webpackChunkName: "productManagement" */ '@/views/productManagement/productBrand/list.vue'),
                meta: {
                  title: '产品品牌列表',
                  icon: 'file-ppt',
                  hidden: true,
                  permission: 'M_productBrandList'
                }
              }
            ]
          },
          {
            path: '/productManagement/productCategory',
            redirect: '/productManagement/productCategory/list',
            name: 'productCategory',
            component: BlankLayout,
            meta: {
              title: '产品分类管理',
              icon: 'radar-chart',
              permission: 'M_productCategoryList'
            },
            hideChildrenInMenu: true,
            children: [
              {
                path: 'list',
                name: 'productCategoryList',
                component: () => import(/* webpackChunkName: "productManagement" */ '@/views/productManagement/productCategory/list.vue'),
                meta: {
                  title: '产品分类列表',
                  icon: 'radar-chart',
                  hidden: true,
                  permission: 'M_productCategoryList'
                }
              }
            ]
          },
          {
            path: '/productManagement/shelfNoManage',
            redirect: '/productManagement/shelfNoManage/list',
            name: 'shelfNoManage',
            component: BlankLayout,
            meta: {
              title: '货位编号管理',
              icon: 'radar-chart',
              permission: 'M_shelfNoManageList'
            },
            hideChildrenInMenu: true,
            children: [
              {
                path: 'list',
                name: 'shelfNoManageList',
                component: () => import(/* webpackChunkName: "productManagement" */ '@/views/productManagement/shelfNoManage/list.vue'),
                meta: {
                  title: '货位编号管理',
                  icon: 'radar-chart',
                  hidden: true,
                  permission: 'M_shelfNoManageList'
                }
              }
            ]
          },
          {
            path: '/productManagement/productSourcePath',
            redirect: '/productManagement/productSourcePath/list',
            name: 'productSourcePath',
            component: BlankLayout,
            meta: {
              title: '唯一码追溯列表',
              icon: 'radar-chart',
              permission: 'M_productSourcePathList'
            },
            hideChildrenInMenu: true,
            children: [
              {
                path: 'list',
                name: 'productSourcePathList',
                component: () => import(/* webpackChunkName: "productManagement" */ '@/views/productManagement/productSourcePath/list.vue'),
                meta: {
                  title: '唯一码追溯列表',
                  icon: 'radar-chart',
                  hidden: true,
                  permission: 'M_productSourcePathList'
                }
              }
            ]
          }
        ]
      }