import {
  UserLayout,
  BasicLayout,
  BlankLayout,
  BigScreen,
  PageView
} from '@/layouts'

export default {
        path: '/salesReport',
        redirect: '/reportData/salesOrderTotal',
        component: PageView,
        meta: {
          title: '销售报表',
          icon: 'project',
          permission: 'M_salesReport'
        },
        children: [
          {
            path: '/reportData/salesOrderTotal',
            redirect: '/reportData/salesOrderTotal/list',
            name: 'salesOrderTotal',
            component: BlankLayout,
            meta: {
              title: '销售(开单统计)',
              icon: 'profile',
              permission: 'M_salesOrderTotalList'
            },
            hideChildrenInMenu: true,
            children: [
              {
                path: 'list',
                name: 'salesOrderTotalList',
                component: () => import(/* webpackChunkName: "reportData" */ '@/views/reportData/salesOrderTotal/list.vue'),
                meta: {
                  title: '销售(开单统计)列表',
                  icon: 'profile',
                  hidden: true,
                  permission: 'M_salesOrderTotalList'
                }
              }
            ]
          },
          {
            path: '/reportData/salesDetails',
            redirect: '/reportData/salesDetails/list',
            name: 'salesDetails',
            component: BlankLayout,
            meta: {
              title: '销售明细(下推统计)',
              icon: 'profile',
              permission: 'M_salesDetailsList'
            },
            hideChildrenInMenu: true,
            children: [
              {
                path: 'list',
                name: 'salesDetailsList',
                component: () => import(/* webpackChunkName: "reportData" */ '@/views/reportData/salesDetails/list.vue'),
                meta: {
                  title: '销售明细(下推统计)列表',
                  icon: 'profile',
                  hidden: true,
                  permission: 'M_salesDetailsList'
                }
              }
            ]
          },
          {
            path: '/reportData/actualSalesReport',
            redirect: '/reportData/actualSalesReport/list',
            name: 'actualSalesReport',
            component: BlankLayout,
            meta: {
              title: '实售销售报表',
              icon: 'profile',
              permission: 'M_actualSalesReportList'
            },
            hideChildrenInMenu: true,
            children: [
              {
                path: 'list',
                name: 'actualSalesReportList',
                component: () => import(/* webpackChunkName: "reportData" */ '@/views/reportData/actualSalesReport/list.vue'),
                meta: {
                  title: '实售销售列表',
                  icon: 'profile',
                  hidden: true,
                  permission: 'M_actualSalesReportList'
                }
              }
            ]
          },
          {
            path: '/reportData/salesAmountReport',
            redirect: '/reportData/salesAmountReport/list',
            name: 'salesAmountReport',
            component: BlankLayout,
            meta: {
              title: '开单销售报表',
              icon: 'profile',
              permission: 'M_salesAmountReportList'
            },
            hideChildrenInMenu: true,
            children: [{
              path: 'list',
              name: 'salesAmountReportList',
              component: () => import(/* webpackChunkName: "reportData" */ '@/views/reportData/salesAmountReport/list.vue'),
              meta: {
                title: '开单销售报表列表',
                icon: 'profile',
                hidden: true,
                permission: 'M_salesAmountReportList'
              }
            }]
          },
          {
            path: '/reportData/salesSlipReport',
            redirect: '/reportData/salesSlipReport/list',
            name: 'salesSlipReport',
            component: BlankLayout,
            meta: {
              title: '开单销售单报表',
              icon: 'profile',
              permission: 'M_salesSlipReportList'
            },
            hideChildrenInMenu: true,
            children: [{
              path: 'list',
              name: 'salesSlipReportList',
              component: () => import(/* webpackChunkName: "reportData" */ '@/views/reportData/salesSlipReport/list.vue'),
              meta: {
                title: '开单销售单报表列表',
                icon: 'profile',
                hidden: true,
                permission: 'M_salesSlipReportList'
              }
            }]
          },
          {
            path: '/reportData/promotionSalesRealTimeReport',
            redirect: '/reportData/promotionSalesRealTimeReport/index',
            name: 'promotionSalesRealTimeReport',
            component: BlankLayout,
            meta: {
              title: '促销销售单报表',
              icon: 'profile',
              permission: 'M_promotionSalesRealTimeReportList'
            },
            hideChildrenInMenu: true,
            children: [
              {
                path: 'index',
                name: 'promotionSalesRealTimeReportIndex',
                component: () => import(/* webpackChunkName: "reportData" */ '@/views/reportData/promotionSalesRealTimeReport/index.vue'),
                meta: {
                  title: '促销销售单报表',
                  icon: 'profile',
                  hidden: true,
                  permission: 'M_promotionSalesRealTimeReportList'
                }
              }
            ]
          },
          {
            path: '/reportData/promotionSalesOrderReport',
            redirect: '/reportData/promotionSalesOrderReport/list',
            name: 'promotionSalesOrderReport',
            component: BlankLayout,
            meta: {
              title: '促销销售单报表（统计）',
              icon: 'profile',
              permission: 'M_promotionSalesOrderReport'
            },
            hideChildrenInMenu: true,
            children: [{
              path: 'list',
              name: 'promotionSalesOrderReportList',
              component: () => import(/* webpackChunkName: "reportData" */ '@/views/reportData/promotionSalesOrderReport/list.vue'),
              meta: {
                title: '促销销售单报表（统计）',
                icon: 'profile',
                hidden: true,
                permission: 'M_promotionSalesOrderReportList'
              }
            }]
          },
          {
            path: '/reportData/salesReturnsReport',
            redirect: '/reportData/salesReturnsReport/list',
            name: 'salesReturnsReport',
            component: BlankLayout,
            meta: {
              title: '销售退货单报表',
              icon: 'profile',
              permission: 'M_salesReturnsReportList'
            },
            hideChildrenInMenu: true,
            children: [
              {
                path: 'list',
                name: 'salesReturnsReportList',
                component: () => import(/* webpackChunkName: "reportData" */ '@/views/reportData/salesReturnsReport/list.vue'),
                meta: {
                  title: '销售退货单报表列表',
                  icon: 'profile',
                  hidden: true,
                  permission: 'M_salesReturnsReportList'
                }
              }
            ]
          },
          {
            path: '/reportData/salesReturnDetailReport',
            redirect: '/reportData/salesReturnDetailReport/list',
            name: 'salesReturnDetailReport',
            component: BlankLayout,
            meta: {
              title: '销售退货明细报表',
              icon: 'profile',
              permission: 'M_salesReturnDetailReportList'
            },
            hideChildrenInMenu: true,
            children: [{
              path: 'list',
              name: 'salesReturnDetailReportList',
              component: () => import(/* webpackChunkName: "reportData" */
                '@/views/reportData/salesReturnDetailReport/list.vue'),
              meta: {
                title: '销售退货明细报表列表',
                icon: 'profile',
                hidden: true,
                permission: 'M_salesReturnDetailReportList'
              }
            }]
          },
          {
            path: '/reportData/salesReturnReport',
            redirect: '/reportData/salesReturnReport/list',
            name: 'salesReturnReport',
            component: BlankLayout,
            meta: {
              title: '实售退货报表',
              icon: 'profile',
              permission: 'M_salesReturnReportList'
            },
            hideChildrenInMenu: true,
            children: [
              {
                path: 'list',
                name: 'salesReturnReportList',
                component: () => import(/* webpackChunkName: "reportData" */ '@/views/reportData/salesReturnReport/list.vue'),
                meta: {
                  title: '实售退货列表',
                  icon: 'profile',
                  hidden: true,
                  permission: 'M_salesReturnReportList'
                }
              }
            ]
          },
          {
            path: '/reportData/billingReturnReport',
            redirect: '/reportData/billingReturnReport/list',
            name: 'billingReturnReport',
            component: BlankLayout,
            meta: {
              title: '开单退货报表',
              icon: 'profile',
              permission: 'M_billingReturnReportList'
            },
            hideChildrenInMenu: true,
            children: [
              {
                path: 'list',
                name: 'billingReturnReportList',
                component: () => import(/* webpackChunkName: "reportData" */ '@/views/reportData/billingReturnReport/list.vue'),
                meta: {
                  title: '开单退货列表',
                  icon: 'profile',
                  hidden: true,
                  permission: 'M_billingReturnReportList'
                }
              }
            ]
          },
          {
            path: '/reportData/returnSlipReport',
            redirect: '/reportData/returnSlipReport/list',
            name: 'returnSlipReport',
            component: BlankLayout,
            meta: {
              title: '开单退货单报表',
              icon: 'profile',
              permission: 'M_returnSlipReportList'
            },
            hideChildrenInMenu: true,
            children: [{
              path: 'list',
              name: 'returnSlipReportList',
              component: () => import(/* webpackChunkName: "reportData" */
                '@/views/reportData/returnSlipReport/list.vue'),
              meta: {
                title: '开单退货单报表列表',
                icon: 'profile',
                hidden: true,
                permission: 'M_returnSlipReportList'
              }
            }]
          },
          {
            path: '/reportData/regionTypeSalesReport',
            redirect: '/reportData/regionTypeSalesReport/list',
            name: 'regionTypeSalesReport',
            component: BlankLayout,
            meta: {
              title: '各分区品类实售明细',
              icon: 'profile',
              permission: 'M_regionTypeSalesReportList'
            },
            hideChildrenInMenu: true,
            children: [
              {
                path: 'list',
                name: 'regionTypeSalesReportList',
                component: () => import(/* webpackChunkName: "reportData" */ '@/views/reportData/regionTypeSalesReport/list.vue'),
                meta: {
                  title: '各分区品类实售明细',
                  icon: 'profile',
                  hidden: true,
                  permission: 'M_regionTypeSalesReportList'
                }
              }
            ]
          },
          {
            path: '/reportData/salesPresentation',
            redirect: '/reportData/salesPresentation/list',
            name: 'salesPresentation',
            component: BlankLayout,
            meta: {
              title: '销售交单报表',
              icon: 'profile',
              permission: 'M_salesPresentationList'
            },
            hideChildrenInMenu: true,
            children: [
              {
                path: 'list',
                name: 'salesPresentationList',
                component: () => import(/* webpackChunkName: "reportData" */ '@/views/reportData/salesPresentation/list.vue'),
                meta: {
                  title: '销售交单报表列表',
                  icon: 'profile',
                  hidden: true,
                  permission: 'M_salesPresentationList'
                }
              }
            ]
          },
          {
            path: '/reportData/returnGoodsPresentation',
            redirect: '/reportData/returnGoodsPresentation/list',
            name: 'returnGoodsPresentation',
            component: BlankLayout,
            meta: {
              title: '退货交单报表',
              icon: 'profile',
              permission: 'M_returnGoodsPresentationList'
            },
            hideChildrenInMenu: true,
            children: [
              {
                path: 'list',
                name: 'returnGoodsPresentationList',
                component: () => import(/* webpackChunkName: "reportData" */ '@/views/reportData/returnGoodsPresentation/list.vue'),
                meta: {
                  title: '退货交单报表列表',
                  icon: 'profile',
                  hidden: true,
                  permission: 'M_returnGoodsPresentationList'
                }
              }
            ]
          },
        ]
      }