import {
  UserLayout,
  BasicLayout,
  BlankLayout,
  BigScreen,
  PageView
} from '@/layouts'

export default {
        path: '/salesReturnManagement',
        redirect: '/salesReturnManagement/salesReturn',
        component: PageView,
        meta: {
          title: '销售退货',
          icon: 'export',
          permission: 'M_salesReturnManagement'
        },
        children: [
          {
            path: '/salesReturnManagement/salesReturn',
            redirect: '/salesReturnManagement/salesReturn/list',
            name: 'salesReturn',
            component: BlankLayout,
            meta: {
              title: '销售退货列表',
              icon: 'fund',
              permission: 'M_salesReturnList'
            },
            hideChildrenInMenu: true,
            children: [
              {
                path: 'list',
                name: 'salesReturnList',
                component: () => import(/* webpackChunkName: "salesReturnManagement" */ '@/views/salesReturnManagement/salesReturn/list.vue'),
                meta: {
                  title: '销售退货列表',
                  icon: 'fund',
                  hidden: true,
                  permission: 'M_salesReturnList'
                }
              },
              {
                path: 'detail/:sn',
                name: 'salesReturnDetail',
                component: () => import(/* webpackChunkName: "salesReturnManagement" */ '@/views/salesReturnManagement/salesReturn/detail.vue'),
                meta: {
                  title: '销售退货详情',
                  icon: 'fund',
                  hidden: true,
                  permission: 'B_salesReturnDetail'
                }
              },
              {
                path: 'salesReturnEdit/:sn/:buyerSn',
                name: 'salesReturnEdit',
                component: () => import(/* webpackChunkName: "salesReturnManagement" */ '@/views/salesReturnManagement/salesReturn/salesReturnEdit.vue'),
                meta: {
                  title: '编辑销售退货',
                  icon: 'fund',
                  hidden: true,
                  permission: 'B_salesReturnEdit'
                }
              },
              {
                path: 'custConfirm/:sn/:buyerSn',
                name: 'custConfirm',
                component: () => import(/* webpackChunkName: "salesReturnManagement" */ '@/views/salesReturnManagement/custConfirm/list.vue'),
                meta: {
                  title: '客服确认',
                  icon: 'fund',
                  replaceTab: true,
                  hidden: true,
                  permission: 'B_salesReturnConfirm'
                }
              }
            ]
          },
          {
            path: '/salesReturnManagement/billOfLading',
            redirect: '/salesReturnManagement/billOfLading/list',
            name: 'billOfLading',
            component: BlankLayout,
            meta: {
              title: '提货单列表',
              icon: 'fund',
              permission: 'M_billOfLadingList'
            },
            hideChildrenInMenu: true,
            children: [
              {
                path: 'list',
                name: 'billOfLadingList',
                component: () => import(/* webpackChunkName: "salesReturnManagement" */ '@/views/salesReturnManagement/billOfLading/list.vue'),
                meta: {
                  title: '提货单列表',
                  icon: 'fund',
                  hidden: true,
                  permission: 'M_billOfLadingList'
                }
              },
              {
                path: 'detail/:sn',
                name: 'billOfLadingDetail',
                component: () => import(/* webpackChunkName: "salesReturnManagement" */ '@/views/salesReturnManagement/billOfLading/detail.vue'),
                meta: {
                  title: '提货单详情',
                  icon: 'fund',
                  hidden: true,
                  permission: 'M_detailPickUp'
                }
              },
              {
                path: 'add',
                name: 'billOfLadingAdd',
                component: () => import(/* webpackChunkName: "salesReturnManagement" */ '@/views/salesReturnManagement/billOfLading/add.vue'),
                meta: {
                  title: '新增提货单',
                  icon: 'fund',
                  hidden: true,
                  permission: 'B_editPickUp'
                }
              },
              {
                path: 'edit/:sn/:wSn',
                name: 'billOfLadingEdit',
                component: () => import(/* webpackChunkName: "salesReturnManagement" */ '@/views/salesReturnManagement/billOfLading/add.vue'),
                meta: {
                  title: '编辑提货单',
                  icon: 'fund',
                  hidden: true,
                  permission: 'B_editPickUp'
                }
              }
            ]
          },
          {
            path: '/salesReturnManagement/pickUp',
            redirect: '/salesReturnManagement/pickUp/list',
            name: 'pickUp',
            component: BlankLayout,
            meta: {
              title: '仓库提货',
              icon: 'fund',
              permission: 'M_pickUpList'
            },
            hideChildrenInMenu: true,
            children: [
              {
                path: 'list',
                name: 'pickUpList',
                component: () => import(/* webpackChunkName: "salesReturnManagement" */ '@/views/salesReturnManagement/pickUp/list.vue'),
                meta: {
                  title: '仓库提货列表',
                  icon: 'fund',
                  hidden: true,
                  permission: 'M_pickUpList'
                }
              }
            ]
          },
          {
            path: '/salesReturnManagement/receiveCheck',
            redirect: '/salesReturnManagement/receiveCheck/list',
            name: 'receiveCheck',
            component: BlankLayout,
            meta: {
              title: '收货品检',
              icon: 'fund',
              permission: 'M_receiveCheckList'
            },
            hideChildrenInMenu: true,
            children: [
              {
                path: 'list',
                name: 'receiveCheckList',
                component: () => import(/* webpackChunkName: "salesReturnManagement" */ '@/views/salesReturnManagement/receiveCheck/list.vue'),
                meta: {
                  title: '收货品检列表',
                  icon: 'fund',
                  hidden: true,
                  permission: 'M_receiveCheckList'
                }
              },
              {
                path: 'receiving/:sn/:buyerSn',
                name: 'salesReturnReceiving',
                component: () => import(/* webpackChunkName: "salesReturnManagement" */ '@/views/salesReturnManagement/receiveCheck/receiving.vue'),
                meta: {
                  title: '收货',
                  icon: 'fund',
                  hidden: true,
                  replaceTab: true,
                  permission: 'B_salesReturnReceiving'
                }
              },
              {
                path: 'checking/:sn/:buyerSn',
                name: 'salesReturnCheck',
                component: () => import(/* webpackChunkName: "salesReturnManagement" */ '@/views/salesReturnManagement/receiveCheck/checking.vue'),
                meta: {
                  title: '品检',
                  icon: 'fund',
                  hidden: true,
                  replaceTab: true,
                  permission: 'B_salesReturnCheck'
                }
              }
            ]
          },
          {
            path: '/salesReturnManagement/returnConfirmation',
            redirect: '/salesReturnManagement/returnConfirmation/list',
            name: 'returnConfirmation',
            component: BlankLayout,
            meta: {
              title: '销售退货确认',
              icon: 'vertical-align-top',
              permission: 'M_returnConfirmationList'
            },
            hideChildrenInMenu: true,
            children: [
              {
                path: 'list',
                name: 'returnConfirmationList',
                component: () => import(/* webpackChunkName: "salesReturnManagement" */ '@/views/salesReturnManagement/returnConfirmation/list.vue'),
                meta: {
                  title: '销售退货确认列表',
                  icon: 'vertical-align-top',
                  hidden: true,
                  permission: 'M_returnConfirmationList'
                }
              }
            ]
          },
          {
            path: '/salesReturnManagement/returnSchedule',
            redirect: '/salesReturnManagement/returnSchedule/list',
            name: 'returnSchedule',
            component: BlankLayout,
            meta: {
              title: '退货一览表',
              icon: 'vertical-align-top',
              permission: 'M_returnScheduleList'
            },
            hideChildrenInMenu: true,
            children: [
              {
                path: 'list',
                name: 'returnScheduleList',
                component: () => import(/* webpackChunkName: "salesReturnManagement" */ '@/views/salesReturnManagement/returnSchedule/list.vue'),
                meta: {
                  title: '退货一览表',
                  icon: 'vertical-align-top',
                  hidden: true,
                  permission: 'M_returnScheduleList'
                }
              }
            ]
          }
        ]
      }