import {
  UserLayout,
  BasicLayout,
  BlankLayout,
  BigScreen,
  PageView
} from '@/layouts'

export default {
  path: '/setting',
  redirect: '/basicData/warehouse',
  component: PageView,
  meta: {
    title: '系统设置',
    icon: 'setting',
    permission: 'M_systemSet'
  },
  children: [
    {
      path: '/basicData/warehouse',
      redirect: '/basicData/warehouse/list',
      name: 'warehouse',
      component: BlankLayout,
      meta: {
        title: '仓库管理',
        icon: 'deployment-unit',
        permission: 'M_warehouseList'
      },
      hideChildrenInMenu: true,
      children: [
        {
          path: '/basicData/warehouse/list',
          name: 'warehouseList',
          component: () => import(/* webpackChunkName: "basicData" */ '@/views/basicData/warehouse/list.vue'),
          meta: {
            title: '仓库列表',
            icon: 'deployment-unit',
            hidden: true,
            permission: 'M_warehouseList'
          }
        },
        {
          path: '/basicData/storingLocation/:sn',
          name: 'storingLocationList',
          component: () => import(/* webpackChunkName: "setting" */ '@/views/basicData/warehouse/storingLocation/list.vue'),
          meta: {
            title: '仓位列表',
            icon: 'deployment-unit',
            replaceTab: true,
            hidden: true
          }
        }
      ]
    },
    {
      path: '/auth/user',
      redirect: '/auth/user/list',
      name: 'powerUser',
      component: BlankLayout,
      meta: {
        title: '用户管理',
        icon: 'user',
        permission: 'M_userList'
      },
      hideChildrenInMenu: true,
      children: [
        {
          path: 'list',
          name: 'powerUserList',
          component: () => import(/* webpackChunkName: "auth" */ '@/views/power/user/userList.vue'),
          meta: {
            title: '用户管理',
            icon: 'user',
            hidden: true,
            permission: 'M_userList'
          }
        }
      ]
    },
    {
      path: '/auth/role',
      redirect: '/auth/role/list',
      name: 'powerRole',
      component: BlankLayout,
      meta: {
        title: '角色管理',
        icon: 'solution',
        permission: 'M_roleList'
      },
      hideChildrenInMenu: true,
      children: [
        {
          path: 'list',
          name: 'powerRoleList',
          component: () => import(/* webpackChunkName: "auth" */ '@/views/power/role/roleList.vue'),
          meta: {
            title: '角色管理',
            icon: 'solution',
            hidden: true,
            permission: 'M_roleList'
          }
        }
      ]
    },
    {
      path: '/auth/adminMenus',
      redirect: '/auth/adminMenus/list',
      name: 'adminMenus',
      component: BlankLayout,
      meta: {
        title: '菜单管理',
        icon: 'appstore',
        permission: 'M_menuList'
      },
      hideChildrenInMenu: true,
      children: [
        {
          path: 'list',
          name: 'adminMenusList',
          component: () => import(/* webpackChunkName: "auth" */ '@/views/bnSetting/menu/adminMenus.vue'),
          meta: {
            title: '菜单管理',
            icon: 'appstore',
            hidden: true,
            permission: 'M_menuList'
          }
        }
      ]
    },
    {
      path: '/setting/dataDictionary',
      redirect: '/setting/dataDictionary/list',
      name: 'dataDictionary',
      component: BlankLayout,
      meta: {
        title: '数据字典管理',
        icon: 'database',
        permission: 'M_dataD_lookup'
      },
      hideChildrenInMenu: true,
      children: [
        {
          path: 'list',
          name: 'powerDD',
          component: () => import(/* webpackChunkName: "setting" */ '@/views/power/dataDictionary/dataDictionary.vue'),
          meta: {
            title: '数据字典管理',
            icon: 'database',
            hidden: true,
            permission: 'M_dataD_lookup'
          }
        }
      ]
    },
    {
      path: '/setting/OperateJournal',
      redirect: '/setting/OperateJournal/list',
      name: 'OperateJournal',
      component: BlankLayout,
      meta: {
        title: '操作日志',
        icon: 'read',
        permission: 'M_OperateJournalList'
      },
      hideChildrenInMenu: true,
      children: [
        {
          path: 'list',
          name: 'powerOperateJournal',
          component: () => import(/* webpackChunkName: "setting" */ '@/views/power/OperateJournal/OperateJournal.vue'),
          meta: {
            title: '操作日志',
            icon: 'read',
            permission: 'M_OperateJournalList'
          }
        }
      ]
    },
    {
      path: '/setting/noticeManagement',
      redirect: '/setting/noticeManagement/list',
      name: 'noticeManagement',
      component: BlankLayout,
      meta: {
        title: '公告管理',
        icon: 'sketch',
        permission: 'M_noticeManagementList'
      },
      hideChildrenInMenu: true,
      children: [
        {
          path: 'list',
          name: 'noticeManagementList',
          component: () => import(/* webpackChunkName: "setting" */ '@/views/setting/noticeManagement/list.vue'),
          meta: {
            title: '公告列表',
            icon: 'sketch',
            hidden: true,
            permission: 'M_noticeManagementList'
          }
        }
      ]
    },
    {
      path: '/setting/bigScreenSet',
      redirect: '/setting/bigScreenSet/index',
      name: 'bigScreenSet',
      component: BlankLayout,
      meta: {
        title: '大屏参数设置',
        icon: 'sketch',
        permission: 'M_bigScreenSetIndex'
      },
      hideChildrenInMenu: true,
      children: [{
        path: 'index',
        name: 'bigScreenSetIndex',
        component: () => import(/* webpackChunkName: "setting" */'@/views/setting/bigScreenSet/index.vue'),
        meta: {
          title: '大屏参数设置',
          icon: 'sketch',
          hidden: true,
          permission: 'M_bigScreenSetIndex'
        }
      }]
    },
    {
      path: '/setting/erpMessageManagement',
      redirect: '/setting/erpMessageManagement/list',
      name: 'erpMessageManagement',
      component: BlankLayout,
      meta: {
        title: 'ERP数据同步记录',
        icon: 'sketch',
        permission: 'M_erpMessageList'
      },
      hideChildrenInMenu: true,
      children: [
        {
          path: 'list',
          name: 'erpMessageManagementList',
          component: () => import(/* webpackChunkName: "setting" */ '@/views/setting/erpMessageManagement/list.vue'),
          meta: {
            title: 'ERP数据同步列表',
            icon: 'sketch',
            hidden: true,
            permission: 'M_erpMessageList'
          }
        }
      ]
    },
    {
      path: '/setting/erpAllotSettings',
      redirect: '/setting/erpAllotSettings/list',
      name: 'erpAllotSettings',
      component: BlankLayout,
      meta: {
        title: '调拨类型管理',
        icon: 'sketch',
        permission: 'M_transferTypeManagementList'
      },
      hideChildrenInMenu: true,
      children: [
        {
          path: 'list',
          name: 'erpAllotSettingsList',
          component: () => import(/* webpackChunkName: "setting" */ '@/views/setting/erpAllotSettings/list.vue'),
          meta: {
            title: '调拨类型管理',
            icon: 'sketch',
            hidden: true,
            permission: 'M_transferTypeManagementList'
          }
        }
      ]
    },
    {
      path: '/setting/dataValidManagement',
      redirect: '/setting/dataValidManagement/list',
      name: 'dataValidManagement',
      component: BlankLayout,
      meta: {
        title: '数据校验管理',
        icon: 'sketch',
        permission: 'M_dataVailidManageList'
      },
      hideChildrenInMenu: true,
      children: [
        {
          path: 'list',
          name: 'dataValidManagementList',
          component: () => import(/* webpackChunkName: "setting" */ '@/views/setting/dataValidManagement/list.vue'),
          meta: {
            title: '数据校验管理',
            icon: 'sketch',
            hidden: true,
            permission: 'M_dataVailidManageList'
          }
        }
      ]
    },
    {
      path: '/setting/tireSubsidySetting',
      redirect: '/setting/tireSubsidySetting/index',
      name: 'tireSubsidySetting',
      component: BlankLayout,
      meta: {
        title: '轮胎补贴配置',
        icon: 'sketch',
        permission: 'M_tireSubsidySetting'
      },
      hideChildrenInMenu: true,
      children: [
        {
          path: 'index',
          name: 'tireSubsidySettingIndex',
          component: () => import(/* webpackChunkName: "setting" */ '@/views/setting/tireSubsidySetting/index.vue'),
          meta: {
            title: '轮胎补贴配置',
            icon: 'sketch',
            hidden: true,
            permission: 'M_tireSubsidySettingIndex'
          }
        }
      ]
    },
    {
      path: '/setting/checkDingTask',
      redirect: '/setting/checkDingTask/list',
      name: 'checkDingTask',
      component: BlankLayout,
      meta: {
        title: '钉钉审批',
        icon: 'sketch',
        permission: 'M_dingAuditUpdate'
      },
      hideChildrenInMenu: true,
      children: [
        {
          path: 'list',
          name: 'checkDingTaskList',
          component: () => import(/* webpackChunkName: "setting" */ '@/views/setting/checkDingTask/list.vue'),
          meta: {
            title: '钉钉审批',
            icon: 'sketch',
            hidden: true,
            permission: 'M_dingAuditUpdate'
          }
        }
      ]
    }
  ]
}
